==> chromium-47.0.2511.3.tar.xz: chromium-47.0.2511.3/components/history/core/test/history_client_fake_bookmarks.h <==
// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_HISTORY_CORE_TEST_HISTORY_CLIENT_FAKE_BOOKMARKS_H_
#define COMPONENTS_HISTORY_CORE_TEST_HISTORY_CLIENT_FAKE_BOOKMARKS_H_

#include "base/memory/ref_counted.h"
#include "base/strings/string16.h"
#include "components/history/core/browser/history_client.h"

class GURL;

namespace history {

class FakeBookmarkDatabase;
class HistoryBackendClient;

// The class HistoryClientFakeBookmarks implements HistoryClient faking the
// methods relating to bookmarks for unit testing.
class HistoryClientFakeBookmarks : public HistoryClient {
 public:
  HistoryClientFakeBookmarks();
  ~HistoryClientFakeBookmarks() override;

  void ClearAllBookmarks();
  void AddBookmark(const GURL& url);
  void AddBookmarkWithTitle(const GURL& url, const base::string16& title);
  void DelBookmark(const GURL& url);
  bool IsBookmarked(const GURL& url);

  // HistoryClient implementation.
  void OnHistoryServiceCreated(HistoryService* history_service) override;
  void Shutdown() override;
  bool CanAddURL(const GURL& url) override;
  void NotifyProfileError(sql::InitStatus init_status) override;
  void PostAfterStartupTask(
      const scoped_refptr<base::SequencedTaskRunner>& task_runner,
      const base::Closure& task) override;
  scoped_ptr<HistoryBackendClient> CreateBackendClient() override;

 private:
  scoped_refptr<FakeBookmarkDatabase> bookmarks_;

  DISALLOW_COPY_AND_ASSIGN(HistoryClientFakeBookmarks);
};

}  // namespace history

#endif  // COMPONENTS_HISTORY_CORE_TEST_HISTORY_CLIENT_FAKE_BOOKMARKS_H_

==> chromium-53.0.2785.101.tar.xz: chromium-53.0.2785.101/components/history/core/test/history_client_fake_bookmarks.h <==
// Copyright 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef COMPONENTS_HISTORY_CORE_TEST_HISTORY_CLIENT_FAKE_BOOKMARKS_H_
#define COMPONENTS_HISTORY_CORE_TEST_HISTORY_CLIENT_FAKE_BOOKMARKS_H_

#include "base/macros.h"
#include "base/memory/ref_counted.h"
#include "base/strings/string16.h"
#include "components/history/core/browser/history_client.h"

class GURL;

namespace history {

class FakeBookmarkDatabase;
class HistoryBackendClient;

// The class HistoryClientFakeBookmarks implements HistoryClient faking the
// methods relating to bookmarks for unit testing.
class HistoryClientFakeBookmarks : public HistoryClient {
 public:
  HistoryClientFakeBookmarks();
  ~HistoryClientFakeBookmarks() override;

  void ClearAllBookmarks();
  void AddBookmark(const GURL& url);
  void AddBookmarkWithTitle(const GURL& url, const base::string16& title);
  void DelBookmark(const GURL& url);
  bool IsBookmarked(const GURL& url);

  // HistoryClient implementation.
  void OnHistoryServiceCreated(HistoryService* history_service) override;
  void Shutdown() override;
  bool CanAddURL(const GURL& url) override;
  void NotifyProfileError(sql::InitStatus init_status) override;
  std::unique_ptr<HistoryBackendClient> CreateBackendClient() override;

 private:
  scoped_refptr<FakeBookmarkDatabase> bookmarks_;

  DISALLOW_COPY_AND_ASSIGN(HistoryClientFakeBookmarks);
};

}  // namespace history

#endif  // COMPONENTS_HISTORY_CORE_TEST_HISTORY_CLIENT_FAKE_BOOKMARKS_H_
